<?php

declare(strict_types=1);

namespace Drupal\Tests\graphql_webform\Kernel\Element;

use Drupal\Tests\graphql_webform\Kernel\GraphQLWebformKernelTestBase;

/**
 * Tests for the WebformElementManagedFile type.
 *
 * @group graphql_webform
 */
class ManagedFileTest extends GraphQLWebformKernelTestBase {

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();

    // Set the max file size to 80KB.
    $this->config('webform.settings')
      ->set('file.default_max_filesize', '80 KB')
      ->save();
  }

  /**
   * Tests managed files.
   */
  public function testManagedFile(): void {
    $query = $this->getQueryFromFile('managed_file.gql');
    $this->assertResults($query, ['id' => 'graphql_webform_test_form'], [
      'form' => [
        'title' => 'GraphQL Webform test form',
        'elements' => [
          6 => [
            '__typename' => 'WebformElementManagedFile',
            'maxFilesize' => 2097152,
            'fileExtensions' => 'gif jpg png txt',
            'metadata' => [
              '__typename' => 'WebformElementMetadata',
              'key' => 'file_upload',
              'type' => 'managed_file',
              'title' => 'File upload',
            ],
          ],
          11 => [
            '__typename' => 'WebformElementWebformAudioFile',
            'maxFilesize' => 81920,
            'fileExtensions' => 'mp3 ogg wav',
            'metadata' => [
              '__typename' => 'WebformElementMetadata',
              'key' => 'audio_files',
              'type' => 'webform_audio_file',
              'title' => 'Audio files',
            ],
          ],
        ],
      ],
    ], $this->defaultCacheMetaData());
  }

}
